aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/vme/vme_bridge.h
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/vme/vme_bridge.h')
-rw-r--r--drivers/vme/vme_bridge.h25
1 files changed, 19 insertions, 6 deletions
diff --git a/drivers/vme/vme_bridge.h b/drivers/vme/vme_bridge.h
index 934949abd745..b59cbee231dd 100644
--- a/drivers/vme/vme_bridge.h
+++ b/drivers/vme/vme_bridge.h
@@ -1,6 +1,8 @@
#ifndef _VME_BRIDGE_H_
#define _VME_BRIDGE_H_
+#include <linux/vme.h>
+
#define VME_CRCSR_BUF_SIZE (508*1024)
/*
* Resource structures
@@ -75,10 +77,13 @@ struct vme_lm_resource {
int monitors;
};
-struct vme_bus_error {
+struct vme_error_handler {
struct list_head list;
- unsigned long long address;
- u32 attributes;
+ unsigned long long start; /* Beginning of error window */
+ unsigned long long end; /* End of error window */
+ unsigned long long first_error; /* Address of the first error */
+ u32 aspace; /* Address space of error window*/
+ unsigned num_errors; /* Number of errors */
};
struct vme_callback {
@@ -88,7 +93,7 @@ struct vme_callback {
struct vme_irq {
int count;
- struct vme_callback callback[255];
+ struct vme_callback callback[VME_NUM_STATUSID];
};
/* Allow 16 characters for name (including null character) */
@@ -106,8 +111,10 @@ struct vme_bridge {
struct list_head dma_resources;
struct list_head lm_resources;
- struct list_head vme_errors; /* List for errors generated on VME */
- struct list_head devices; /* List of devices on this bridge */
+ /* List for registered errors handlers */
+ struct list_head vme_error_handlers;
+ /* List of devices on this bridge */
+ struct list_head devices;
/* Bridge Info - XXX Move to private structure? */
struct device *parent; /* Parent device (eg. pdev->dev for PCI) */
@@ -166,9 +173,15 @@ struct vme_bridge {
void *vaddr, dma_addr_t dma);
};
+void vme_bus_error_handler(struct vme_bridge *bridge,
+ unsigned long long address, int am);
void vme_irq_handler(struct vme_bridge *, int, int);
int vme_register_bridge(struct vme_bridge *);
void vme_unregister_bridge(struct vme_bridge *);
+struct vme_error_handler *vme_register_error_handler(
+ struct vme_bridge *bridge, u32 aspace,
+ unsigned long long address, size_t len);
+void vme_unregister_error_handler(struct vme_error_handler *handler);
#endif /* _VME_BRIDGE_H_ */